# 🎁 Release notes (0.7)

## Changes
```
fix: fixed tempalted not being included
ref: fixed pypi readme markdown
ref: updated history md
fix: format
fix: github somehow ignored the newline
ref: updated changes log
fix: fixed errors on macos
ref: renamed
ref: updated doc; changelog
feat: usable
fix: fixed entrypoint; fixed version style
ref: rm redundant code
```

## Metadata
```
This version -------- 0.7
Previous version ---- 0.1
Total commits ------- 12
```
